@@ -159,7 +159,7 @@ present' originally was 1.
 
 =head1 AUTHOR
 
-Pl Sannes E<lt>pal.sannes@met.noE<gt>
+Pål Sannes E<lt>pal.sannes@met.noE<gt>
 
 =head1 COPYRIGHT
 
