@@ -377,7 +377,7 @@ additional info.
                     should be added to existing value. Use 'missing'
                     to set a missing value. Repeat the option if more
                     sequence descriptors are to be set. Example:
-                    --data 004004=-1+ --data 00405=50 --data
+                    --data 004004=-1+ --data 004005=50 --data
                     012101=missing This will set the data value for
                     first (and only first!) occurrence of these 3
                     descriptors in every subset and every message in
@@ -435,7 +435,7 @@ bufralter.pl works for you).
 
 =head1 AUTHOR
 
-Pl Sannes E<lt>pal.sannes@met.noE<gt>
+Pål Sannes E<lt>pal.sannes@met.noE<gt>
 
 =head1 COPYRIGHT
 
