@@ -300,7 +300,7 @@ Options may be abbreviated, e.g. C<--h> or C<-h> for C<--help>
 
 =head1 AUTHOR
 
-Pl Sannes E<lt>pal.sannes@met.noE<gt>
+Pål Sannes E<lt>pal.sannes@met.noE<gt>
 
 =head1 COPYRIGHT
 
