@@ -567,7 +567,7 @@ combined with 204YYY (add associated field operator).
 
 =head1 AUTHOR
 
-Pl Sannes E<lt>pal.sannes@met.noE<gt>
+Pål Sannes E<lt>pal.sannes@met.noE<gt>
 
 =head1 COPYRIGHT
 
